Struct amazon_sp_fba_inbound_eligibility::models::item_eligibility_preview::ItemEligibilityPreview
source · [−]pub struct ItemEligibilityPreview {
pub asin: String,
pub marketplace_id: Option<String>,
pub program: Program,
pub is_eligible_for_program: bool,
pub ineligibility_reason_list: Option<Vec<IneligibilityReasonList>>,
}Expand description
ItemEligibilityPreview : The response object which contains the ASIN, marketplaceId if required, eligibility program, the eligibility status (boolean), and a list of ineligibility reason codes.
Fields
asin: StringThe ASIN for which eligibility was determined.
marketplace_id: Option<String>The marketplace for which eligibility was determined.
program: ProgramThe program for which eligibility was determined.
is_eligible_for_program: boolIndicates if the item is eligible for the program.
ineligibility_reason_list: Option<Vec<IneligibilityReasonList>>Potential Ineligibility Reason Codes.
Implementations